@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -39,7 +39,7 @@ using namespace KABMergeContacts;
 MergeContactsDialog::MergeContactsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Select Contacts to merge"));
+    setWindowTitle(i18nc("@title:window", "Select Contacts to merge"));
     mButtonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     mButtonBox->setObjectName(QStringLiteral("buttonbox"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
