@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class QTextStream;
 class MarkdownHighlighter : public KSyntaxHighlighting::AbstractHighlighter
 {
 public:
-    MarkdownHighlighter(QTextStream *stream);
+    explicit MarkdownHighlighter(QTextStream *stream);
     ~MarkdownHighlighter() override;
 
     void highlight(const QString &str);
