@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,10 +22,8 @@
 
 #include <QObject>
 
-class KActionCollection;
 
 class QAbstractItemModel;
-class QAction;
 class QItemSelectionModel;
 class QuicktextManager : public QObject
 {
